<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:src ="http://purl.oclc.org/dsdl/9573-11amd1/ns/structure/1.0"
  xmlns:fo="http://www.w3.org/1999/XSL/Format" version="1.0">
  <xsl:template name="toc">
    <fo:block break-before="page">
    <fo:table table-layout="fixed">
      <fo:table-column column-width="490pt"/>
      <fo:table-column column-width="20pt"/>
      <fo:table-body>
        <fo:table-row display-align="before" height="2.5em">
          <fo:table-cell text-align="start">
            <fo:block>
              <fo:inline xsl:use-attribute-sets="h1">
                <xsl:call-template name="contstr">
                  <xsl:with-param name="lang" select="$lng"/>
                </xsl:call-template>
              </fo:inline>
              <fo:leader leader-pattern="space"/>
            </fo:block>
          </fo:table-cell>
          <fo:table-cell text-align="end">
            <fo:block text-align-last="end">
              <xsl:text>Page</xsl:text>
            </fo:block>
          </fo:table-cell>
        </fo:table-row>
        <xsl:apply-templates select="src:foreword|src:introduction|src:scope|src:conf|src:normative-references|src:terms-and-definitions|//src:clause|src:annex|src:bibliography|src:index" mode="toc" />
      </fo:table-body>
    </fo:table>
  </fo:block>
  </xsl:template>

  <xsl:template match="src:foreword" mode="toc">
    <xsl:call-template name="toc-ent">
      <xsl:with-param name="anc">foreword</xsl:with-param>
      <xsl:with-param name="text">
        <xsl:call-template name="forewordstr">
          <xsl:with-param name="lang" select="$lng"/>
        </xsl:call-template>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="src:introduction" mode="toc">
    <xsl:call-template name="toc-ent">
      <xsl:with-param name="anc">introduction</xsl:with-param>
      <xsl:with-param name="text">Introduction</xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <xsl:template name="toc-ent">
    <xsl:param name="anc" />
    <xsl:param name="text" />
    <xsl:param name="indnt" select="'0mm'"/>
    <fo:table-row display-align="after" height="2em">
      <fo:table-cell text-align="start">
        <fo:block start-indent="{$indnt}" text-align-last="justify">
          <xsl:value-of select="$text"/>
          <fo:leader leader-pattern="dots" leader-pattern-width="4pt"
            leader-alignment="reference-area"/>
        </fo:block>
      </fo:table-cell>
      <fo:table-cell text-align="end">
        <fo:block>
          <fo:page-number-citation ref-id="{$anc}"/>
        </fo:block>
      </fo:table-cell>
    </fo:table-row>
  </xsl:template>

  <xsl:template match="src:scope" mode="toc">
    <xsl:variable name="nth">
      <xsl:number level="multiple" count="src:scope|src:conf|src:normative-references|src:terms-and-definitions|src:clause" />
    </xsl:variable>
    <xsl:variable name="text">
      <xsl:call-template name="scopestr">
        <xsl:with-param name="lang" select="$lng"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:call-template name="toc-ent">
      <xsl:with-param name="anc" select="$nth" />
      <xsl:with-param name="text" select="concat($nth, ' ', $text)" />
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="src:conf">
    <xsl:call-template name="toc-ent">
      <xsl:with-param name="anc">conformance</xsl:with-param>
      <xsl:with-param name="text">Conformance</xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="src:normative-references" mode="toc">
    <xsl:variable name="nth">
      <xsl:number level="multiple" count="src:scope|src:conf|src:normative-references|src:terms-and-definitions|src:clause" />
    </xsl:variable>
    <xsl:variable name="text">
      <xsl:call-template name="normativereferencesstr">
        <xsl:with-param name="lang" select="$lng"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:call-template name="toc-ent">
      <xsl:with-param name="anc" select="$nth" />
      <xsl:with-param name="text" select="concat($nth, ' ', $text)" />
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="src:terms-and-definitions" mode="toc">
    <xsl:variable name="nth">
      <xsl:number level="multiple" count="src:scope|src:conf|src:normative-references|src:terms-and-definitions|clause" />
    </xsl:variable>
    <xsl:variable name="text">
      <xsl:call-template name="termsanddefinitionsstr">
        <xsl:with-param name="lang" select="$lng"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:call-template name="toc-ent">
      <xsl:with-param name="anc" select="$nth" />
      <xsl:with-param name="text" select="concat($nth, ' ', $text)" />
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="src:clause" mode="toc">
    <xsl:variable name="level" select="count(ancestor::src:clause|ancestor::src:annex)" />
    <xsl:variable name="indnt">
      <xsl:choose>
        <xsl:when test="$level=1"><xsl:value-of select="$halfquote"/></xsl:when>
        <xsl:when test="$level=2"><xsl:value-of select="$quote"/></xsl:when>
        <xsl:when test="$level=3"><xsl:value-of select="$widequote"/></xsl:when>
        <xsl:otherwise>0mm</xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:variable name="nth">
      <xsl:choose>
        <xsl:when test="ancestor::src:annex">
          <xsl:number level="multiple" count="src:annex|src:annex//src:clause" format="A.1" />
        </xsl:when>
        <xsl:otherwise>
          <xsl:number level="multiple" count="src:scope|src:conf|src:normative-references|src:terms-and-definitions|src:clause" format="1.1" />
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:call-template name="toc-ent">
      <xsl:with-param name="anc" select="$nth" />
      <xsl:with-param name="text">
        <xsl:value-of select="$nth" />
        <xsl:text> </xsl:text>
        <xsl:apply-templates select="src:title" mode="toc"/>
      </xsl:with-param>
      <xsl:with-param name="indnt" select="$indnt"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="src:title" mode="toc">
    <xsl:apply-templates mode="toc"/>
  </xsl:template>
  
  <xsl:template match="src:footnote" mode="toc"/>
  
  <xsl:template match="src:annex" mode="toc">
    <xsl:variable name="nth">
      <xsl:number level="multiple" count="src:annex" format="A" />
    </xsl:variable>
    <xsl:call-template name="toc-ent">
      <xsl:with-param name="anc" select="$nth" />
      <xsl:with-param name="text">
        <xsl:value-of select="$nth" />
        <xsl:text> </xsl:text>
        <xsl:apply-templates select="src:title" mode="toc"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="src:bibliography" mode="toc">
    <xsl:call-template name="toc-ent">
      <xsl:with-param name="anc">bibliography</xsl:with-param>
      <xsl:with-param name="text">
        <xsl:call-template name="bibliographystr">
          <xsl:with-param name="lang" select="$lng"/>
        </xsl:call-template>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="src:index" mode="toc">
    <xsl:call-template name="toc-ent">
      <xsl:with-param name="anc">index</xsl:with-param>
      <xsl:with-param name="text">Index</xsl:with-param>
    </xsl:call-template>
  </xsl:template>
</xsl:stylesheet>

